Learn R Programming

JSparO (version 1.5.0)

L2NewtonThr: L2NewtonThr - Iterative Thresholding Algorithm based on \(l_{2,q}\) norm with Newton method

Description

The function aims to solve \(l_{2,q}\) regularized least squares, where the proximal optimization subproblems will be solved by Newton method.

Usage

L2NewtonThr(A, B, X, s, q, maxIter = 200, innMaxIter = 30, innEps = 1e-06)

Value

The solution of proximal gradient method with \(l_{2,q}\) regularizer.

Arguments

A

Gene expression data of transcriptome factors (i.e. feature matrix in machine learning). The dimension of A is m * n.

B

Gene expression data of target genes (i.e. observation matrix in machine learning). The dimension of B is m * t.

X

Gene expression data of Chromatin immunoprecipitation or other matrix (i.e. initial iterative point in machine learning). The dimension of X is n * t.

s

joint sparsity level

q

value for \(l_{2,q}\) norm (i.e., 0 < q < 1)

maxIter

maximum iteration

innMaxIter

maximum iteration in Newton step

innEps

criterion to stop inner iteration

Details

The L2NewtonThr function aims to solve the problem: $$\min \|AX-B\|_F^2 + \lambda \|X\|_{2,q}$$ to obtain s-joint sparse solution.

Examples

Run this code
m <- 256; n <- 1024; t <- 5; maxIter0 <- 50
A0 <- matrix(rnorm(m * n), nrow = m, ncol = n)
B0 <- matrix(rnorm(m * t), nrow = m, ncol = t)
X0 <- matrix(0, nrow = n, ncol = t)
NoA <- norm(A0, '2'); A0 <- A0/NoA; B0 <- B0/NoA
res_L2q <- L2NewtonThr(A0, B0, X0, s = 10, q = 0.2, maxIter = maxIter0)

Run the code above in your browser using DataLab